@@ -1,4 +1,4 @@
-def bubble_sort(list: list) -> list:
+def sort(list: list) -> list:
     '''
     How it works:
     Step 1. Start While Loop
