@@ -1,4 +1,4 @@
-def insertion_sort(lst: list) -> list:
+def sort(lst: list) -> list:
     '''
     How it works:
     Step 1. Iterate over set starting at element[1], for loop
