@@ -1,4 +1,4 @@
-def selection_sort(unsorted_lst: list) -> list:
+def sort(unsorted_lst: list) -> list:
     '''
     How it works:
     Step 1. Find 1st smallest element in the list, swap with element list[0]
